@@ -38,7 +38,7 @@ class opensshStatus(hildondesktop.StatusMenuItem):
     def start(self):
         self.confirmDisconnect = True
         self.stopTracking = False
-        self.skipSystemCheck = False
+        skipSystemCheck = False
         if path.isfile("/home/user/.openssh-status-widget"):
             parser = SafeConfigParser()
             try:
@@ -47,7 +47,7 @@ class opensshStatus(hildondesktop.StatusMenuItem):
                 self.stopTracking = parser.getboolean('options', 'stopTracking')
                 skipSystemCheck = parser.getboolean('options', 'skipSystemCheck')
             except:
-                subprocess.call(["sudo", "rm", "/home/user/.openssh-status-widget"])
+                subprocess.call(["rm", "/home/user/.openssh-status-widget"])
             
         sshSystemStart = False
         sshSystemRespawn = False
@@ -115,7 +115,7 @@ class opensshStatus(hildondesktop.StatusMenuItem):
         self.dialog.show_all()
         
     def adjustYes(self, dummy):
-        subprocess.call(["sudo", "sed", "-i", "s/respawn/#respawn/g", "/etc/event.d/sshd"])
+        subprocess.call(["sudo", "/usr/sbin/openssh-status.sh", "disable_respawn"])
         self.dialog.destroy()
         message = gtk.Dialog("OpenSSH status", None)
         text = gtk.Label("Done! Please reboot the N900.")
@@ -185,7 +185,7 @@ class opensshStatus(hildondesktop.StatusMenuItem):
     def buttonClicked(self, dummy):
         self.sshStatus()
         if self.sshRunning and self.on:
-            subprocess.call(["sudo", "/etc/init.d/ssh", "stop"])
+            subprocess.call(["sudo", "/usr/sbin/openssh-status.sh", "stop_sshd"])
             time.sleep(0.5)
             self.sshStatus()
             if self.sshRunning:
@@ -212,7 +212,7 @@ class opensshStatus(hildondesktop.StatusMenuItem):
             self.printDialog("OpenSSH Server already running! Display corrected.")
         else:
             self.sshUsers()
-            subprocess.call(["sudo", "/etc/init.d/ssh", "start"])
+            subprocess.call(["sudo", "/usr/sbin/openssh-status.sh", "start_sshd"])
             time.sleep(0.5)
             self.sshStatus()
             if self.sshRunning:
@@ -256,7 +256,7 @@ class opensshStatus(hildondesktop.StatusMenuItem):
         self.sshStatus()
         self.sshUsers()
         if self.sshRunning:
-            subprocess.call(["sudo", "killall", "sshd"])
+            subprocess.call(["sudo", "/usr/sbin/openssh-status.sh", "kill_sshd"])
             time.sleep(0.5)
             self.sshStatus()
             self.sshUsers()
@@ -270,7 +270,7 @@ class opensshStatus(hildondesktop.StatusMenuItem):
                 self.button.set_image(self.image_off)
                 self.set_status_area_icon()
         elif self.sshConnected:
-            subprocess.call(["sudo", "killall", "sshd"])
+            subprocess.call(["sudo", "/usr/sbin/openssh-status.sh", "kill_sshd"])
             time.sleep(0.5)
             self.sshUsers()
             if self.sshConnected:
